@@ -33,7 +33,7 @@ mapping = {
     8216: '-',
     8211: '-',
     167: '-',
-    8364: 'euro'
+    8364: 'euro',
 }
 
 
